This function allows us to quickly define an alpha parameter for a Dirichlet distribution with a single (presumably high) peak*scale value at component i and all other components a uniform (presumably low) value (1-peak)/(k-1)*scale.
See also
Other generators:
draw_corpus(),
journal_specific(),
rdirichlet()